package com.phm.manage.mapper;

import com.phm.manage.domain.FalseAlarmRestrainModel;

import java.util.List;

/**
 * 虚警抑制模型Mapper接口
 *
 * @author phm
 * @date 2023-08-22
 */
public interface FalseAlarmRestrainModelMapper {
    /**
     * 查询虚警抑制模型
     *
     * @param id 虚警抑制模型主键
     * @return 虚警抑制模型
     */
    public FalseAlarmRestrainModel selectFalseAlarmRestrainModelById(Long id);

    /**
     * 查询虚警抑制模型列表
     *
     * @param falseAlarmRestrainModel 虚警抑制模型
     * @return 虚警抑制模型集合
     */
    public List<FalseAlarmRestrainModel> selectFalseAlarmRestrainModelList(FalseAlarmRestrainModel falseAlarmRestrainModel);

    /**
     * 新增虚警抑制模型
     *
     * @param falseAlarmRestrainModel 虚警抑制模型
     * @return 结果
     */
    public int insertFalseAlarmRestrainModel(FalseAlarmRestrainModel falseAlarmRestrainModel);

    /**
     * 修改虚警抑制模型
     *
     * @param falseAlarmRestrainModel 虚警抑制模型
     * @return 结果
     */
    public int updateFalseAlarmRestrainModel(FalseAlarmRestrainModel falseAlarmRestrainModel);

    /**
     * 删除虚警抑制模型
     *
     * @param id 虚警抑制模型主键
     * @return 结果
     */
    public int deleteFalseAlarmRestrainModelById(Long id);

    /**
     * 批量删除虚警抑制模型
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteFalseAlarmRestrainModelByIds(Long[] ids);
}
